# User Profile

## Identity

- Name:
- Timezone:
- Language:

## Role & Mindset

(How the user works, what they value, their technical depth.)

## Active Projects

(List of current projects the user is working on.)

## Communication Style

(Preferences for response format, length, tone.)
